import { Spin } from 'antd';
import { useEffect, useRef } from 'react';

export default function ScrollLoading({
  loading,
  children,
  totalLength, //当前请求到的数据总长度
  pagination = { current: 1, total: 0 },
  handleLoadData, //请求数据方法
  height = 90, //除滚动区域外其他高度(只是通用标题就是90)
}) {
  const bottomAreaOfList = useRef();
  const scrollContent = useRef();
  // 是否已经发送请求 防止发送多次同样的请求
  const load = useRef();

  console.log('-----------------', pagination);

  const handleScroll = () => {
    const { current, total } = pagination;
    if (totalLength >= total) {
      return;
    }
    const rect = bottomAreaOfList.current.getBoundingClientRect();
    const isVisible =
      rect.top >= 0 &&
      rect.left >= 0 &&
      rect.bottom <=
        (scrollContent.current.innerHeight ||
          document.documentElement.clientHeight) &&
      rect.right <=
        (scrollContent.current.innerWidth ||
          document.documentElement.clientWidth);

    if (isVisible && !load.current) {
      load.current = true;
      handleLoadData(current + 1);
    }
  };

  // 监听滚动事件
  useEffect(() => {
    load.current = false;
    scrollContent.current.addEventListener('scroll', handleScroll);
    return () => {
      scrollContent.current.removeEventListener('scroll', handleScroll);
    };
  }, [loading]);

  return (
    <Spin spinning={loading}>
      <div
        ref={scrollContent}
        style={{ overflowY: 'scroll', height: `calc(100vh - ${height + 1}px)` }}
      >
        {children}
        <div
          ref={bottomAreaOfList}
          style={{
            height: '1px',
          }}
        />
        <div />
      </div>
    </Spin>
  );
}
